@@ -95,6 +95,10 @@ sub result {
         # unescape the resulting path
         $result = uri_unescape($result->path);
 
+        if ($uri->query) {
+            $result .= "?" . uri_unescape($uri->query);
+        }
+
         if ($uri->fragment) {
             $result .= "#" . uri_unescape($uri->fragment);
         }
@@ -111,7 +115,7 @@ Stefan Hornburg (Racke), <racke@linuxia.de>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014-2019 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2014-2021 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
